Changelog
---------

Version 1.0.0
*************
* Drop backward compatibilty.
* Tested and status upgraded to Production/Stable.

Version 0.0.3
*************
* Make parameter fields in WOW animations optional.

Version 0.0.2
*************
* Fixed packaging issues.
* Added tests to cover all plugins.
* Add south and django migrations.
* Drop support for Python 2.6.

Version 0.0.1
*************
* Initial Release.
